//*****************************************************************************
//
// qtmixer - an X windows soundcard mixer program.
// Copyright (C) 1997 - 2000  Tom Daley
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// The license is in the file COPYING.
//
// Tom Daley
// 1309 W. Lorraine Ave.
// Woodland Park, CO  80863-2329
//
// daley@codenet.net (Tom Daley)
// http://users.codenet.net/daley
//
//*****************************************************************************

#include <stream.h>
#include <string.h>
#include <stdlib.h>

#include <qapp.h>
#include <qintdict.h>

#include "TedError.h"
#include "mixer.h"

//*****************************************************************************
//
// To override the channel labels given by the kernel sound driver use:
//  "qtmixer -labelX Foo"
// where X is the channel number starting with 0.
//

main (int argc, char **argv) {
   char *cp;
   int i, result = 0;
   QString mixer_name = "/dev/mixer";
   QFont font ("adobe", 12, QFont::Bold);
   QFont::setDefaultFont(font);
   QIntDict<QString> title_dict;

   i = 0;
   while (i < argc) {
      if (strncmp(argv[i], "-label", 6) == 0) {
         char *cp;
         int ch_num;
         cp = &argv[i][6];	// extract channel number
         ch_num = atoi(cp);	// Add entry to dictionary
         title_dict.insert(ch_num, new QString(argv[i+1]));
         int src, dst;		// remove from argument list
         for (dst = i, src = i + 2; src < argc;) {
            argv[dst++] = argv[src++];
         }
         argc-=2;
      } else {
         i++;
      }
   }

   QApplication a(argc, argv);

   if (a.argc() > 1)
      mixer_name = a.argv()[1]; 

   QtedMixer mixer(title_dict, mixer_name);
   QtedError err;
   err.setDialog(1);
   QObject::connect(&mixer, SIGNAL(error(QString *)),
           &err, SLOT(reportError(QString *)));

   if (mixer.valid()) {
      a.setMainWidget(&mixer);
      mixer.show();
      result = a.exec();
   } else {
      result = -1;
      cerr << "ERROR: " << mixer.errorString() << "\n";
   }

   return (result);
}

//*****************************************************************************
